import { ClientConfig } from '../../clients/hatchet-client/client-config';
import WorkflowRunRef from '../../util/workflow-run-ref';
import { Priority, RateLimitDuration, RunsClient } from './..';
import { RunListenerClient } from '../../clients/listeners/run-listener/child-listener-client';
import { Api } from '../../clients/rest/generated/Api';
import { WorkflowServiceClient } from '../../protoc/workflows';
import { Logger } from '../../util/logger';
export type WorkflowRun<T = object> = {
    workflowName: string;
    input: T;
    options?: {
        parentId?: string | undefined;
        parentStepRunId?: string | undefined;
        childIndex?: number | undefined;
        childKey?: string | undefined;
        additionalMetadata?: Record<string, string> | undefined;
    };
};
export declare class AdminClient {
    config: ClientConfig;
    grpc: WorkflowServiceClient;
    listenerClient: RunListenerClient;
    runs: RunsClient;
    logger: Logger;
    constructor(config: ClientConfig, api: Api, runs: RunsClient);
    /**
     * Run a new instance of a workflow with the given input. This will create a new workflow run and return the ID of the
     * new run.
     * @param workflowName the name of the workflow to run
     * @param input an object containing the input to the workflow
     * @param options an object containing the options to run the workflow
     * @returns the ID of the new workflow run
     */
    runWorkflow<Q = object, P = object>(workflowName: string, input: Q, options?: {
        parentId?: string | undefined;
        parentStepRunId?: string | undefined;
        childIndex?: number | undefined;
        childKey?: string | undefined;
        additionalMetadata?: Record<string, string> | undefined;
        desiredWorkerId?: string | undefined;
        priority?: Priority;
    }): Promise<WorkflowRunRef<P>>;
    /**
     * Run multiple workflows runs with the given input and options. This will create new workflow runs and return their IDs.
     * Order is preserved in the response.
     * @param workflowRuns an array of objects containing the workflow name, input, and options for each workflow run
     * @returns an array of workflow run references
     */
    runWorkflows<Q = object, P = object>(workflowRuns: Array<{
        workflowName: string;
        input: Q;
        options?: {
            parentId?: string | undefined;
            parentStepRunId?: string | undefined;
            childIndex?: number | undefined;
            childKey?: string | undefined;
            additionalMetadata?: Record<string, string> | undefined;
            desiredWorkerId?: string | undefined;
            priority?: Priority;
        };
    }>, batchSize?: number): Promise<WorkflowRunRef<P>[]>;
    private batchWorkflows;
    putRateLimit(key: string, limit: number, duration?: RateLimitDuration): Promise<void>;
}
